@@ -1,5 +1,4 @@
-from rocketgym.environment import *
-
+from src.rocketgym.environment import Environment
 import random
 
 env = Environment()
